@@ -219,7 +219,7 @@ nma <- function(network,
       if (any(!ns_check$valid)) {
         ns_valid <- dplyr::filter(ns_check, .data$valid) %>%
           dplyr::ungroup() %>%
-          dplyr::select(.data$trt1, .data$trt2)
+          dplyr::select("trt1", "trt2")
 
         ns_invalid <- dplyr::filter(ns_check, !.data$valid) %>%
           dplyr::mutate(comparison = paste(.data$trt1, .data$trt2, sep = " vs. "))
@@ -605,13 +605,13 @@ nma <- function(network,
     }
 
     if (has_agd_arm(network)) {
-      tdat_agd_arm <- dplyr::select(dat_agd_arm, .data$.study, .data$.trt)
+      tdat_agd_arm <- dplyr::select(dat_agd_arm, ".study", ".trt")
     } else {
       tdat_agd_arm <- tibble::tibble()
     }
 
     if (has_agd_contrast(network)) {
-      tdat_agd_contrast_nonbl <- dplyr::select(dat_agd_contrast_nonbl, .data$.study, .data$.trt)
+      tdat_agd_contrast_nonbl <- dplyr::select(dat_agd_contrast_nonbl, ".study", ".trt")
     } else {
       tdat_agd_contrast_nonbl <- tibble::tibble()
     }
@@ -1930,7 +1930,7 @@ make_nma_model_matrix <- function(nma_formula,
                                             paste0(".study", single_study_label))
     dat_all <- dat_all %>%
       dplyr::mutate(.study = .data$.study_temp) %>%
-      dplyr::select(-.data$.study_temp)
+      dplyr::select(-".study_temp")
 
     # Drop intercept column from design matrix
     X_all <- X_all[, -1, drop = FALSE]
@@ -2075,7 +2075,7 @@ check_regression_data <- function(formula,
 
   # Check that required variables are present in each data set, and non-missing
   if (.has_ipd) {
-    rlang::with_handlers(
+    withCallingHandlers(
       X_ipd_frame <- model.frame(formula, dat_ipd, na.action = NULL),
       error = ~abort(paste0(if (newdata) "Failed to construct design matrix for `newdata`.\n" else "Failed to construct design matrix for IPD.\n", .)))
 
@@ -2085,7 +2085,7 @@ check_regression_data <- function(formula,
   }
 
   if (.has_agd_arm) {
-    rlang::with_handlers(
+    withCallingHandlers(
       X_agd_arm_frame <- model.frame(formula, dat_agd_arm, na.action = NULL),
       error = ~abort(paste0(if (newdata) "Failed to construct design matrix for `newdata`.\n" else "Failed to construct design matrix for AgD (arm-based).\n", .)))
 
@@ -2095,7 +2095,7 @@ check_regression_data <- function(formula,
   }
 
   if (.has_agd_contrast) {
-    rlang::with_handlers(
+    withCallingHandlers(
       X_agd_contrast_frame <- model.frame(formula, dat_agd_contrast, na.action = NULL),
       error = ~abort(paste0(if (newdata) "Failed to construct design matrix for `newdata`.\n" else "Failed to construct design matrix for AgD (contrast-based).\n", .)))
 
